Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(79)

Unified Diff: chrome/browser/ui/app_list/search/search_util.h

Issue 1925733005: Remove people search (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Deprecate people search actions and enum Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/app_list/search/search_controller_factory.cc ('k') | chrome/chrome_browser_ui.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/app_list/search/search_util.h
diff --git a/chrome/browser/ui/app_list/search/search_util.h b/chrome/browser/ui/app_list/search/search_util.h
index 19cd5d1cb11daae47b1ae452c5e3dce75f037569..08a1b3f76e071fa0e6abd23d53feb0cf2121b6b5 100644
--- a/chrome/browser/ui/app_list/search/search_util.h
+++ b/chrome/browser/ui/app_list/search/search_util.h
@@ -18,8 +18,8 @@ enum SearchResultType {
WEBSTORE_SEARCH_RESULT,
// A result that opens a webstore search.
SEARCH_WEBSTORE_SEARCH_RESULT,
- // A result that opens a people search.
- SEARCH_PEOPLE_SEARCH_RESULT,
+ // A result that opens a people search (Deprecated).
+ SEARCH_PEOPLE_SEARCH_RESULT_DEPRECATED,
// A result that opens a suggestion.
SUGGESTIONS_SEARCH_RESULT,
// A result that is provided by the custom launcher search provider.
« no previous file with comments | « chrome/browser/ui/app_list/search/search_controller_factory.cc ('k') | chrome/chrome_browser_ui.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698